@@ -1,18 +1,17 @@
 use strict;
 use warnings;
-package Net::Inspect;
 
-our $VERSION = "0.27_1";
+our $VERSION = 0.01;
 1;
 
 
 =head1 NAME
 
-Net::Inspect - library for inspection of data on various network layers
+Net::Inspect - libary for inspection of data on various network layers
 
 =head1 SYNOPSIS
 
-    use Net::Pcap 'pcap_loop';
+    use Net::Pcap;
     use Net::Inspect::L2::Pcap;
     use Net::Inspect::L3::IP;
     use Net::Inspect::L4::TCP;
@@ -23,13 +22,13 @@ Net::Inspect - library for inspection of data on various network layers
     my $pcap = Net::Pcap->new...
     ...
     my $l7 = Net::Inspect::L7::HTTP->new;
-    my $l4 = Net::Inspect::L4::TCP->new($l7);
+    my $l4 = Net::Inspect::L4::TCP->new($l5);
     my $l3 = Net::Inspect::L3::IP->new($l4);
     my $l2 = Net::Inspect::L2::Pcap->new($pcap,$l3);
 
     pcap_loop($pcap,-1,sub {
-	my (undef,$hdr,$data) = @_;
-	return $l2->pktin($data,$hdr);
+    my (undef,$hdr,$data) = @_;
+    return $l2->pktin($data,$hdr);
     });
 
 =head1 DESCRIPTION
@@ -41,7 +40,7 @@ therefore slower to execute but faster to develop and maybe more flexibel
 too.
 
 One can start analysis on some level and stop it at any higher level.
-There are various useful tools in tools/ which make use of this library:
+There are various useful tools in bin/ which make use of this library:
 
 =over 4
 
@@ -85,10 +84,6 @@ processes raw IP packets, does defragmentation.
 handles TCP connections, e.g. connection setup and shutdown and reordering
 of packets.
 
-=item L<Net::Inspect::L4::UDP>
-
-handles UDP packets. Can aggregate udp packets in virtual connections.
-
 =item L<Net::Inspect::L5::GuessProtocol>
 
 tries to guess the higher level protocol from TCP connections.
@@ -126,7 +121,7 @@ Steffen Ullrich, <sullr@cpan.org>
 
 =head1 COPYRIGHT
 
-  Copyright 2011-2013 Steffen Ullrich
+  Copyright 2011 Steffen Ullrich
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
